SearchBarWidget class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SearchBarWidget
Constructors
- SearchBarWidget({Key? key, required String label, required dynamic onSearchChanged(String), dynamic onFilterChanged()?, bool? filter = false, bool? focus = true, TextStyle? labelStyle, Widget? searchIcon, Widget? clearIcon, String? hintText, Widget? filterIcon, TextStyle? hintStyle, Color? cursorColor, bool? centerTitle = true})
-
label - String ,isRequired : No
onSearchChanged - Function(String) ,isRequired : No
onFilterChanged - Function() ,isRequired : No
searchDecoration - InputDecoration ,isRequired : No
searchStyle - TextStyle ,isRequired : No
cursorColor - Color ,isRequired : No
isFilter - bool - default true
searchEnabled - bool - default true
const
Properties
- centerTitle → bool?
-
final
- clearIcon → Widget?
-
final
- cursorColor → Color?
-
final
- filter → bool?
-
final
- filterIcon → Widget?
-
final
- focus → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintStyle → TextStyle?
-
final
- hintText → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- labelStyle → TextStyle?
-
final
- onFilterChanged → dynamic Function()?
-
final
- onSearchChanged → dynamic Function(String)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchIcon → Widget?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited